summaryrefslogtreecommitdiff
path: root/chromium/net/disk_cache/simple/simple_histogram_macros.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/disk_cache/simple/simple_histogram_macros.h')
-rw-r--r--chromium/net/disk_cache/simple/simple_histogram_macros.h39
1 files changed, 22 insertions, 17 deletions
diff --git a/chromium/net/disk_cache/simple/simple_histogram_macros.h b/chromium/net/disk_cache/simple/simple_histogram_macros.h
index 2107ad466a7..f800a6f40a3 100644
--- a/chromium/net/disk_cache/simple/simple_histogram_macros.h
+++ b/chromium/net/disk_cache/simple/simple_histogram_macros.h
@@ -10,26 +10,31 @@
#include "net/base/cache_type.h"
// This file contains macros used to report histograms. The main issue is that
// we want to have separate histograms for each type of cache (http vs app),
// while making it easy to report histograms and have all names precomputed.
#define SIMPLE_CACHE_THUNK(uma_type, args) UMA_HISTOGRAM_##uma_type args
-#define SIMPLE_CACHE_UMA(uma_type, uma_name, cache_type, ...) \
- do { \
- switch (cache_type) { \
- case net::DISK_CACHE: \
- SIMPLE_CACHE_THUNK( \
- uma_type, ("SimpleCache.Http." uma_name, ##__VA_ARGS__)); \
- break; \
- case net::APP_CACHE: \
- SIMPLE_CACHE_THUNK( \
- uma_type, ("SimpleCache.App." uma_name, ##__VA_ARGS__)); \
- break; \
- default: \
- NOTREACHED(); \
- break; \
- } \
+#define SIMPLE_CACHE_UMA(uma_type, uma_name, cache_type, ...) \
+ do { \
+ switch (cache_type) { \
+ case net::DISK_CACHE: \
+ SIMPLE_CACHE_THUNK( \
+ uma_type, ("SimpleCache.Http." uma_name, ##__VA_ARGS__)); \
+ break; \
+ case net::APP_CACHE: \
+ SIMPLE_CACHE_THUNK( \
+ uma_type, ("SimpleCache.App." uma_name, ##__VA_ARGS__)); \
+ break; \
+ case net::MEDIA_CACHE: \
+ SIMPLE_CACHE_THUNK( \
+ uma_type, ("SimpleCache.Media." uma_name, ##__VA_ARGS__)); \
+ break; \
+ default: \
+ NOTREACHED(); \
+ break; \
+ } \
} while (0)
#endif // NET_DISK_CACHE_SIMPLE_SIMPLE_HISTOGRAM_MACROS_H_
@@ -10,26 +10,31 @@
#include "net/base/cache_type.h"
// This file contains macros used to report histograms. The main issue is that
-// we want to have separate histograms for each type of cache (http vs app),
-// while making it easy to report histograms and have all names precomputed.
+// we want to have separate histograms for each type of cache (app, http, and
+// media), while making it easy to report histograms and have all names
+// precomputed.
#define SIMPLE_CACHE_THUNK(uma_type, args) UMA_HISTOGRAM_##uma_type args